#[repr(i32)]pub enum AvatarColor {
A100 = 0,
A110 = 1,
A120 = 2,
A130 = 3,
A140 = 4,
A150 = 5,
A160 = 6,
A170 = 7,
A180 = 8,
A190 = 9,
A200 = 10,
A210 = 11,
}Expand description
If unset - computed as the value of the first byte of SHA-256(msg=CONTACT_ID) modulo the count of colors. Once set the avatar color for a recipient is never recomputed or changed.
CONTACT_ID is the first available identifier from the list:
- ServiceIdToBinary(ACI)
- E164
- ServiceIdToBinary(PNI)
- Group Id
Variants
A100 = 0
A110 = 1
A120 = 2
A130 = 3
A140 = 4
A150 = 5
A160 = 6
A170 = 7
A180 = 8
A190 = 9
A200 = 10
A210 = 11
Implementations
Sourceimpl AvatarColor
impl AvatarColor
Sourceimpl AvatarColor
impl AvatarColor
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.