AttachmentPointer

Struct AttachmentPointer 

pub struct AttachmentPointer {
Show 17 fields pub client_uuid: Option<Vec<u8>>, pub content_type: Option<String>, pub key: Option<Vec<u8>>, pub size: Option<u32>, pub thumbnail: Option<Vec<u8>>, pub digest: Option<Vec<u8>>, pub incremental_mac: Option<Vec<u8>>, pub chunk_size: Option<u32>, pub file_name: Option<String>, pub flags: Option<u32>, pub width: Option<u32>, pub height: Option<u32>, pub caption: Option<String>, pub blur_hash: Option<String>, pub upload_timestamp: Option<u64>, pub cdn_number: Option<u32>, pub attachment_identifier: Option<AttachmentIdentifier>,
}

Fields

client_uuid: Option<Vec<u8>>

Cross-client identifier for this attachment among all attachments on the owning message.

content_type: Option<String>key: Option<Vec<u8>>size: Option<u32>thumbnail: Option<Vec<u8>>digest: Option<Vec<u8>>incremental_mac: Option<Vec<u8>>chunk_size: Option<u32>file_name: Option<String>flags: Option<u32>width: Option<u32>height: Option<u32>caption: Option<String>blur_hash: Option<String>upload_timestamp: Option<u64>cdn_number: Option<u32>

Next ID: 21

attachment_identifier: Option<AttachmentIdentifier>

Implementations

Source

impl AttachmentPointer

pub fn content_type(&self) -> &str

Returns the value of content_type, or the default value if content_type is unset.

pub fn key(&self) -> &[u8]

Returns the value of key, or the default value if key is unset.

pub fn size(&self) -> u32

Returns the value of size, or the default value if size is unset.

pub fn thumbnail(&self) -> &[u8]

Returns the value of thumbnail, or the default value if thumbnail is unset.

pub fn digest(&self) -> &[u8]

Returns the value of digest, or the default value if digest is unset.

pub fn file_name(&self) -> &str

Returns the value of file_name, or the default value if file_name is unset.

pub fn flags(&self) -> u32

Returns the value of flags, or the default value if flags is unset.

pub fn width(&self) -> u32

Returns the value of width, or the default value if width is unset.

pub fn height(&self) -> u32

Returns the value of height, or the default value if height is unset.

pub fn caption(&self) -> &str

Returns the value of caption, or the default value if caption is unset.

pub fn blur_hash(&self) -> &str

Returns the value of blur_hash, or the default value if blur_hash is unset.

pub fn upload_timestamp(&self) -> u64

Returns the value of upload_timestamp, or the default value if upload_timestamp is unset.

pub fn cdn_number(&self) -> u32

Returns the value of cdn_number, or the default value if cdn_number is unset.

pub fn chunk_size(&self) -> u32

Returns the value of chunk_size, or the default value if chunk_size is unset.

pub fn incremental_mac(&self) -> &[u8]

Returns the value of incremental_mac, or the default value if incremental_mac is unset.

pub fn client_uuid(&self) -> &[u8]

Returns the value of client_uuid, or the default value if client_uuid is unset.