ContactRecord

Struct ContactRecord 

pub struct ContactRecord {
Show 26 fields pub aci: String, pub e164: String, pub pni: String, pub profile_key: Vec<u8>, pub identity_key: Vec<u8>, pub identity_state: i32, pub given_name: String, pub family_name: String, pub username: String, pub blocked: bool, pub whitelisted: bool, pub archived: bool, pub marked_unread: bool, pub muted_until_timestamp: u64, pub hide_story: bool, pub unregistered_at_timestamp: u64, pub system_given_name: String, pub system_family_name: String, pub system_nickname: String, pub hidden: bool, pub pni_signature_verified: bool, pub nickname: Option<Name>, pub note: String, pub avatar_color: Option<i32>, pub aci_binary: Vec<u8>, pub pni_binary: Vec<u8>,
}

Fields

aci: Stringe164: Stringpni: Stringprofile_key: Vec<u8>identity_key: Vec<u8>identity_state: i32given_name: Stringfamily_name: Stringusername: Stringblocked: boolwhitelisted: boolarchived: boolmarked_unread: boolmuted_until_timestamp: u64hide_story: boolunregistered_at_timestamp: u64system_given_name: Stringsystem_family_name: Stringsystem_nickname: Stringhidden: boolpni_signature_verified: boolnickname: Option<Name>note: Stringavatar_color: Option<i32>aci_binary: Vec<u8>

16-byte UUID

pni_binary: Vec<u8>

16-byte UUID

Implementations

Source

impl ContactRecord

pub fn identity_state(&self) -> IdentityState

Returns the enum value of identity_state, or the default if the field is set to an invalid enum value.

pub fn set_identity_state(&mut self, value: IdentityState)

Sets identity_state to the provided enum value.

pub fn avatar_color(&self) -> AvatarColor

Returns the enum value of avatar_color, or the default if the field is unset or set to an invalid enum value.

pub fn set_avatar_color(&mut self, value: AvatarColor)

Sets avatar_color to the provided enum value.