Envelope

Struct Envelope 

pub struct Envelope {
Show 17 fields pub type: Option<i32>, pub source_service_id: Option<String>, pub source_device: Option<u32>, pub destination_service_id: Option<String>, pub timestamp: Option<u64>, pub content: Option<Vec<u8>>, pub server_guid: Option<String>, pub server_timestamp: Option<u64>, pub ephemeral: Option<bool>, pub urgent: Option<bool>, pub updated_pni: Option<String>, pub story: Option<bool>, pub report_spam_token: Option<Vec<u8>>, pub source_service_id_binary: Option<Vec<u8>>, pub destination_service_id_binary: Option<Vec<u8>>, pub server_guid_binary: Option<Vec<u8>>, pub updated_pni_binary: Option<Vec<u8>>,
}

Fields

type: Option<i32>source_service_id: Option<String>source_device: Option<u32>destination_service_id: Option<String>timestamp: Option<u64>content: Option<Vec<u8>>

Contains an encrypted Content

server_guid: Option<String>server_timestamp: Option<u64>ephemeral: Option<bool>

indicates that the message should not be persisted if the recipient is offline

urgent: Option<bool>

indicates that the content is considered timely by the sender; defaults to true so senders have to opt-out to say something isn’t time critical

updated_pni: Option<String>

for number-change synchronization messages, provides the new server-assigned phone number identifier associated with the changed number

story: Option<bool>

indicates that the content is a story.

report_spam_token: Option<Vec<u8>>

token sent when reporting spam

source_service_id_binary: Option<Vec<u8>>

service ID binary (i.e. 16 byte UUID for ACI, 1 byte prefix + 16 byte UUID for PNI)

destination_service_id_binary: Option<Vec<u8>>

service ID binary (i.e. 16 byte UUID for ACI, 1 byte prefix + 16 byte UUID for PNI)

server_guid_binary: Option<Vec<u8>>

16-byte UUID

updated_pni_binary: Option<Vec<u8>>

16-byte UUID

Implementations

Source

impl Envelope

pub fn is_unidentified_sender(&self) -> bool

pub fn is_prekey_signal_message(&self) -> bool

pub fn is_receipt(&self) -> bool

pub fn is_signal_message(&self) -> bool

pub fn is_urgent(&self) -> bool

pub fn is_story(&self) -> bool

pub fn source_address(&self) -> ServiceId

👎Deprecated:

use parse_source_service_id

pub fn destination_address(&self) -> ServiceId

👎Deprecated:

use parse_destination_service_id

pub fn parse_destination_service_id(&self) -> Option<ServiceId>

pub fn parse_source_service_id(&self) -> Option<ServiceId>

pub fn parse_server_guid(&self) -> Option<Uuid>

pub fn parse_updated_pni(&self) -> Option<Pni>

Source

impl Envelope

pub fn type(&self) -> Type

Returns the enum value of type, or the default if the field is unset or set to an invalid enum value.

pub fn set_type(&mut self, value: Type)

Sets type to the provided enum value.

pub fn timestamp(&self) -> u64

Returns the value of timestamp, or the default value if timestamp is unset.

pub fn source_device(&self) -> u32

Returns the value of source_device, or the default value if source_device is unset.

pub fn content(&self) -> &[u8]

Returns the value of content, or the default value if content is unset.

pub fn server_guid(&self) -> &str

Returns the value of server_guid, or the default value if server_guid is unset.

pub fn server_timestamp(&self) -> u64

Returns the value of server_timestamp, or the default value if server_timestamp is unset.

pub fn source_service_id(&self) -> &str

Returns the value of source_service_id, or the default value if source_service_id is unset.

pub fn ephemeral(&self) -> bool

Returns the value of ephemeral, or the default value if ephemeral is unset.

pub fn destination_service_id(&self) -> &str

Returns the value of destination_service_id, or the default value if destination_service_id is unset.

pub fn urgent(&self) -> bool

Returns the value of urgent, or the default value if urgent is unset.

pub fn updated_pni(&self) -> &str

Returns the value of updated_pni, or the default value if updated_pni is unset.

pub fn story(&self) -> bool

Returns the value of story, or the default value if story is unset.

pub fn report_spam_token(&self) -> &[u8]

Returns the value of report_spam_token, or the default value if report_spam_token is unset.

pub fn source_service_id_binary(&self) -> &[u8]

Returns the value of source_service_id_binary, or the default value if source_service_id_binary is unset.

pub fn destination_service_id_binary(&self) -> &[u8]

Returns the value of destination_service_id_binary, or the default value if destination_service_id_binary is unset.

pub fn server_guid_binary(&self) -> &[u8]

Returns the value of server_guid_binary, or the default value if server_guid_binary is unset.

pub fn updated_pni_binary(&self) -> &[u8]

Returns the value of updated_pni_binary, or the default value if updated_pni_binary is unset.