pub struct GroupV2Record {
pub master_key: Vec<u8>,
pub blocked: bool,
pub whitelisted: bool,
pub archived: bool,
pub marked_unread: bool,
pub muted_until_timestamp: u64,
pub dont_notify_for_mentions_if_muted: bool,
pub hide_story: bool,
pub story_send_mode: i32,
pub avatar_color: Option<i32>,
}Fields
master_key: Vec<u8>blocked: boolwhitelisted: boolarchived: boolmarked_unread: boolmuted_until_timestamp: u64dont_notify_for_mentions_if_muted: boolhide_story: boolstory_send_mode: i32avatar_color: Option<i32>Implementations
Sourceimpl GroupV2Record
impl GroupV2Record
Sourcepub fn story_send_mode(&self) -> StorySendMode
pub fn story_send_mode(&self) -> StorySendMode
Returns the enum value of story_send_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_story_send_mode(&mut self, value: StorySendMode)
pub fn set_story_send_mode(&mut self, value: StorySendMode)
Sets story_send_mode to the provided enum value.
Sourcepub fn avatar_color(&self) -> AvatarColor
pub fn avatar_color(&self) -> AvatarColor
Returns the enum value of avatar_color, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_avatar_color(&mut self, value: AvatarColor)
pub fn set_avatar_color(&mut self, value: AvatarColor)
Sets avatar_color to the provided enum value.