pub struct NotificationProfile {Show 13 fields
pub id: Vec<u8>,
pub name: String,
pub emoji: Option<String>,
pub color: u32,
pub created_at_ms: u64,
pub allow_all_calls: bool,
pub allow_all_mentions: bool,
pub allowed_members: Vec<Recipient>,
pub schedule_enabled: bool,
pub schedule_start_time: u32,
pub schedule_end_time: u32,
pub schedule_days_enabled: Vec<i32>,
pub deleted_at_timestamp_ms: u64,
}Fields
id: Vec<u8>name: Stringemoji: Option<String>color: u320xAARRGGBB
created_at_ms: u64allow_all_calls: boolallow_all_mentions: boolallowed_members: Vec<Recipient>schedule_enabled: boolschedule_start_time: u3224-hour clock int, 0000-2359 (e.g., 15, 900, 1130, 2345)
schedule_end_time: u3224-hour clock int, 0000-2359 (e.g., 15, 900, 1130, 2345)
schedule_days_enabled: Vec<i32>deleted_at_timestamp_ms: u64Implementations
Sourceimpl NotificationProfile
impl NotificationProfile
Sourcepub fn emoji(&self) -> &str
pub fn emoji(&self) -> &str
Returns the value of emoji, or the default value if emoji is unset.
Sourcepub fn schedule_days_enabled(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<DayOfWeek>>
pub fn schedule_days_enabled( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<DayOfWeek>>
Returns an iterator which yields the valid enum values contained in schedule_days_enabled.
Sourcepub fn push_schedule_days_enabled(&mut self, value: DayOfWeek)
pub fn push_schedule_days_enabled(&mut self, value: DayOfWeek)
Appends the provided enum value to schedule_days_enabled.