ProvisionMessage

Struct ProvisionMessage 

pub struct ProvisionMessage {
Show 18 fields pub aci_identity_key_public: Option<Vec<u8>>, pub aci_identity_key_private: Option<Vec<u8>>, pub pni_identity_key_public: Option<Vec<u8>>, pub pni_identity_key_private: Option<Vec<u8>>, pub aci: Option<String>, pub pni: Option<String>, pub number: Option<String>, pub provisioning_code: Option<String>, pub user_agent: Option<String>, pub profile_key: Option<Vec<u8>>, pub read_receipts: Option<bool>, pub provisioning_version: Option<u32>, pub master_key: Option<Vec<u8>>, pub ephemeral_backup_key: Option<Vec<u8>>, pub account_entropy_pool: Option<String>, pub media_root_backup_key: Option<Vec<u8>>, pub aci_binary: Option<Vec<u8>>, pub pni_binary: Option<Vec<u8>>,
}

Fields

aci_identity_key_public: Option<Vec<u8>>aci_identity_key_private: Option<Vec<u8>>pni_identity_key_public: Option<Vec<u8>>pni_identity_key_private: Option<Vec<u8>>aci: Option<String>pni: Option<String>number: Option<String>provisioning_code: Option<String>user_agent: Option<String>profile_key: Option<Vec<u8>>read_receipts: Option<bool>provisioning_version: Option<u32>master_key: Option<Vec<u8>>

Deprecated, but required by linked devices

ephemeral_backup_key: Option<Vec<u8>>

32 bytes

account_entropy_pool: Option<String>media_root_backup_key: Option<Vec<u8>>

32-bytes

aci_binary: Option<Vec<u8>>

16-byte UUID

pni_binary: Option<Vec<u8>>

16-byte UUID

Implementations

Source

impl ProvisionMessage

pub fn aci_identity_key_public(&self) -> &[u8]

Returns the value of aci_identity_key_public, or the default value if aci_identity_key_public is unset.

pub fn aci_identity_key_private(&self) -> &[u8]

Returns the value of aci_identity_key_private, or the default value if aci_identity_key_private is unset.

pub fn number(&self) -> &str

Returns the value of number, or the default value if number is unset.

pub fn provisioning_code(&self) -> &str

Returns the value of provisioning_code, or the default value if provisioning_code is unset.

pub fn user_agent(&self) -> &str

Returns the value of user_agent, or the default value if user_agent is unset.

pub fn profile_key(&self) -> &[u8]

Returns the value of profile_key, or the default value if profile_key is unset.

pub fn read_receipts(&self) -> bool

Returns the value of read_receipts, or the default value if read_receipts is unset.

pub fn aci(&self) -> &str

Returns the value of aci, or the default value if aci is unset.

pub fn provisioning_version(&self) -> u32

Returns the value of provisioning_version, or the default value if provisioning_version is unset.

pub fn pni(&self) -> &str

Returns the value of pni, or the default value if pni is unset.

pub fn pni_identity_key_public(&self) -> &[u8]

Returns the value of pni_identity_key_public, or the default value if pni_identity_key_public is unset.

pub fn pni_identity_key_private(&self) -> &[u8]

Returns the value of pni_identity_key_private, or the default value if pni_identity_key_private is unset.

pub fn master_key(&self) -> &[u8]

Returns the value of master_key, or the default value if master_key is unset.

pub fn ephemeral_backup_key(&self) -> &[u8]

Returns the value of ephemeral_backup_key, or the default value if ephemeral_backup_key is unset.

pub fn account_entropy_pool(&self) -> &str

Returns the value of account_entropy_pool, or the default value if account_entropy_pool is unset.

pub fn media_root_backup_key(&self) -> &[u8]

Returns the value of media_root_backup_key, or the default value if media_root_backup_key is unset.

pub fn aci_binary(&self) -> &[u8]

Returns the value of aci_binary, or the default value if aci_binary is unset.

pub fn pni_binary(&self) -> &[u8]

Returns the value of pni_binary, or the default value if pni_binary is unset.