pub struct SyncMessage {
pub read: Vec<Read>,
pub sticker_pack_operation: Vec<StickerPackOperation>,
pub viewed: Vec<Viewed>,
pub padding: Option<Vec<u8>>,
pub content: Option<Content>,
}Fields
read: Vec<Read>Protobufs don’t allow repeated fields to be inside of oneof so while
the fields below are mutually exclusive with the rest of the values above
we have to place them outside of oneof.
sticker_pack_operation: Vec<StickerPackOperation>viewed: Vec<Viewed>padding: Option<Vec<u8>>content: Option<Content>Implementations
Sourceimpl SyncMessage
impl SyncMessage
Sourceimpl SyncMessage
impl SyncMessage
pub fn with_padding<R: Rng + CryptoRng>(csprng: &mut R) -> Self